@@ -1,6 +1,8 @@
+setnames <- `names<-`
+
 patterns <-
   c(rsprintf="(?<!%)%[\\s\\+\\-\\#\\.\\d]*\\w",
-    rprintv="(?<!\\$)\\$\\w+(:[\\s\\+\\-\\#\\.\\d]*\\w)?",
+    rprintv="(?<!\\$)\\$[\\w\\.]+(:[\\s\\+\\-\\#\\.\\d]*\\w)?",
     rprintn="(?<!\\{)\\{\\d+(:[\\s\\+\\-\\#\\.\\d]*\\w)?\\}(?!\\})",
     rsprintf=".")
 
